@@ -21,6 +21,7 @@ from http import HTTPStatus
 from urllib.parse import urljoin
 
 import requests
+import os
 from packaging import version
 from requests import HTTPError
 
@@ -87,6 +88,7 @@ class AgentClient:
         self._reporting_thread = threading.Thread(
             target=self.__report_worker, daemon=True
         )
+        self._close_socket = False
         self._reporting_thread.start()
 
         if not self.__start_session():
@@ -191,18 +193,44 @@ class AgentClient:
         )
         return start_session_response
 
-    def send_request(self, method, path, body=None) -> OperationResult:
+    def update_job_name(self, job_name):
+        """Sends HTTP request to Agent to update job name during runtime.
+
+                Args:
+                    job_name (str): new job name to use for the current execution
+                """
+        if os.getenv("TP_UPDATE_JOB_NAME") == "True":
+            logging.info(f"Updating job name to: {job_name}")
+            try:
+                response = self.send_request(
+                    "PUT",
+                    urljoin(self._remote_address, Endpoint.DevelopmentSession.value),
+                    {"jobName": job_name}
+                )
+            except requests.exceptions.RequestException:
+                logging.error(
+                    "Failed to update job name"
+                )
+            if not response.passed:
+                logging.error(
+                    "Failed to update job name"
+                )
+
+    def send_request(self, method, path, body=None, params=None) -> OperationResult:
         """Sends HTTP request to Agent
 
         Args:
             method (str): HTTP method (GET, POST, ...)
             path (str): Relative API route path
             body (dict): Request body
+            params (dict): Request parameters
 
         Returns:
             OperationResult: contains result of the sent request
         """
         with requests.Session() as session:
+            if params:
+                session.params = params
             if method == "GET":
                 response = session.get(path, headers={"Authorization": self._token})
             elif method == "POST":
@@ -211,6 +239,8 @@ class AgentClient:
                 )
             elif method == "DELETE":
                 response = session.delete(path, headers={"Authorization": self._token})
+            elif method == "PUT":
+                response = session.put(path, headers={"Authorization": self._token}, json=body)
             else:
                 raise SdkException(
                     f"Unsupported HTTP method {method} in send_request()"
@@ -372,7 +402,7 @@ class AgentClient:
             )
 
         if not AgentClient.can_reuse_session():
-            SocketManager.instance().close_socket()
+            self._close_socket = True
 
     def execute_proxy(self, action: ActionProxy) -> AddonExecutionResponse:
         """Sends a custom action to the Agent
@@ -387,6 +417,7 @@ class AgentClient:
             "POST",
             urljoin(self._remote_address, Endpoint.AddonExecution.value),
             self._create_action_proxy_payload(action),
+            {"skipReporting": "true"}  # Delegate reporting from Agent to SDK.
         )
 
         if operation_result.status_code == HTTPStatus.NOT_FOUND:
@@ -460,6 +491,9 @@ class AgentClient:
                     f"Unknown object of type {type(item)} found on queue, ignoring it.."
                 )
             self._queue.task_done()
+        # Close socket only after agent_client is no longer running and all reports in the queue have been sent.
+        if self._close_socket:
+            SocketManager.instance().close_socket()
 
 
 class QueueItem:
