@@ -14,11 +14,11 @@
 
 import logging
 import inspect
+import time
 
 from selenium.webdriver.remote.command import Command
 
 from src.testproject.classes import StepSettings
-from src.testproject.enums import TakeScreenshotConditionType
 from src.testproject.helpers import ReportHelper
 from src.testproject.helpers.step_helper import StepHelper
 from src.testproject.rest.messages import DriverCommandReport, CustomTestReport
@@ -56,7 +56,8 @@ class ReportingCommandExecutor:
         self._stashed_command = None
         self._latest_known_test_name = ReportHelper.infer_test_name()
         self._excluded_test_names = list()
-        self._step_helper = StepHelper(remote_connection, agent_client.agent_session.dialect == "W3C")
+        self._step_helper = StepHelper(remote_connection, agent_client.agent_session.dialect == "W3C",
+                                       agent_client.agent_session.session_id)
         self._settings = StepSettings()
 
     @property
@@ -145,7 +146,7 @@ class ReportingCommandExecutor:
         Args:
             command (str): The driver command to execute
             params (dict): Named parameters to send with the command as its JSON payload
-            result (dict): The response returned by the Selenium remote webdriver server
+            result (dict): The response returned by the Selenium remote WebDriver server
             passed (bool): True if the command execution was successful, False otherwise
         """
         if command == Command.QUIT:
@@ -165,22 +166,15 @@ class ReportingCommandExecutor:
                 self._is_webdriverwait = True
                 break
 
-        # Invert result is set?
-        passed = not passed if self.settings.invert_result else passed
+        # Handle step result and message.
+        passed, step_message = self.step_helper.handle_step_result(step_result=passed,
+                                                                   invert_result=self.settings.invert_result,
+                                                                   always_pass=self.settings.always_pass)
+        screenshot = (self.create_screenshot()
+                      if self.step_helper.take_screenshot(self.settings.screenshot_condition, passed)
+                      else None)
 
-        driver_command_report = DriverCommandReport(command, params, result, passed)
-
-        # Is screenshot needed?
-        take_screenshot = False
-        if self.settings.screenshot_condition is TakeScreenshotConditionType.Failure and not passed:
-            take_screenshot = True
-        elif self.settings.screenshot_condition is TakeScreenshotConditionType.Success and passed:
-            take_screenshot = True
-        elif self.settings.screenshot_condition is TakeScreenshotConditionType.Always:
-            take_screenshot = True
-
-        if take_screenshot:
-            driver_command_report.screenshot = self.create_screenshot()
+        driver_command_report = DriverCommandReport(command, params, result, passed, screenshot, step_message)
 
         if self._is_webdriverwait:
             if not self._disable_reports and not self.disable_command_reports:
@@ -269,7 +263,8 @@ class ReportingCommandExecutor:
                 self.agent_client.report_driver_command(self._stashed_command)
                 self._stashed_command = None
 
-    def is_command_passed(self, response: dict) -> bool:
+    @staticmethod
+    def is_command_passed(response: dict) -> bool:
         """Determine command result based on response using state and status.
 
         Args:
@@ -280,3 +275,34 @@ class ReportingCommandExecutor:
         """
         # Both None and 0 response status values indicate command execution was OK
         return True if response.get("status") in [None, 0] else False
+
+    def pause(self, milliseconds: int):
+        """Pause test execution for the specified duration
+
+        Args:
+            self (Union[Remote, BaseDriver]): The driver invoking this pause action.
+            milliseconds (int): Number of milliseconds to pause test execution for.
+        """
+
+        # Handling sleep before execution
+        self.step_helper.handle_sleep(sleep_timing_type=self.step_settings.sleep_timing_type,
+                                      sleep_time=self.step_settings.sleep_time)
+        # Sleep for...
+        time.sleep(milliseconds / 1000.0)
+
+        # Handling sleep after execution
+        self.step_helper.handle_sleep(sleep_timing_type=self.step_settings.sleep_timing_type,
+                                      sleep_time=self.step_settings.sleep_time,
+                                      step_executed=True)
+        result, step_message = self.step_helper.handle_step_result(
+            step_result=True,
+            invert_result=self.step_settings.invert_result,
+            always_pass=self.step_settings.always_pass)
+
+        # Handle screenshot condition
+        screenshot = self.step_helper.take_screenshot(self.step_settings.screenshot_condition, result)
+        self.report().step(description=f'Pause for {{{{{milliseconds}}}}} ms',
+                           message=step_message,
+                           inputs={"milliseconds": milliseconds},
+                           passed=result,
+                           screenshot=screenshot)
